#!/usr/bin/env python
# This file is closely based on tests.py from matplotlib
#
# This allows running the matplotlib tests from the command line: e.g.
#
#   $ python run_tests.py -v -d
#
# The arguments are identical to the arguments accepted by nosetests.
#
# See https://nose.readthedocs.org/ for a detailed description of
# these options.
import nose


env = {"NOSE_WITH_COVERAGE": 1,
       'NOSE_COVER_PACKAGE': ['cycler'],
       'NOSE_COVER_HTML': 1}
plugins = []


def run():

    nose.main(addplugins=[x() for x in plugins], env=env)


if __name__ == '__main__':
    run()



from setuptools import setup

setup(name='cycler',
      version='0.10.0',
      author='Thomas A Caswell',
      author_email='matplotlib-users@python.org',
      py_modules=['cycler'],
      description='Composable style cycles',
      url='http://github.com/matplotlib/cycler',
      platforms='Cross platform (Linux, Mac OSX, Windows)',
      install_requires=['six'],
      license="BSD",
      classifiers=['Development Status :: 4 - Beta',
                   'Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.6',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.3',
                   'Programming Language :: Python :: 3.4',
                   'Programming Language :: Python :: 3.5',
                   ],
      keywords='cycle kwargs',
      )
